explain_var_measure returns explained variation measurement for the grouping scheme.
explain_var_measure(main_list, stage_list, stage_list_2, covar_list, data)main_list includes survival indicator variable, Duration time of survival variable and basic group variable.
stage_list original of each scheme.
stage_list_2 is numerical form of each scheme by using other of stages information.
Covariate variables taking into consideration.
Data set.
Ranking of explained variation measurement and its standardized score.
Xu, W., et al. 'Refining evaluation methodology on TNM stage system: assessment on HPV-related oropharyngeal cancer.' Austin Biometrics and Biostatistics 2 (2015): 1014.