hz_cons_measure returns Hazard consistency for the grouping scheme.
hz_cons_measure(main_list, stage_list, covar_list, data)main_list includes survival indicator variable, Duration time of survival variable and basic group variable.
stage_list is numerical form of each scheme by using other of stages information.
Covariate variables taking into consideration.
Data set.
Ranking of hazard consistency measurement and standardized score.
Xu, W., et al. 'Refining evaluation methodology on TNM stage system: assessment on HPV-related oropharyngeal cancer.' Austin Biometrics and Biostatistics 2 (2015): 1014.